Name:		mrepo
Version:	0.8.7
Release:	2%{?dist}
Summary:	A tool to set up a yum/apt mirror from various sources
License:	GPLv2
Group:		System Environment/Base
URL:		http://dag.wieers.com/home-made/mrepo/
# At time of writing, the latest stable release is not provided as a tarball
#
# svn export http://svn.rpmforge.net/svn/trunk/tools/mrepo/ mrepo-0.8.7
# tar -cvjf mrepo-0.8.7.tar.bz2 mrepo-0.8.7
Source0:	mrepo-%{version}.tar.bz2
# Patch initfile to conform to new standards
Patch0:		mrepo-initd.patch
# Patch to make mounting of ISOs possible with SELinux
Patch1:		mrepo-selinux.patch
# Patch to fix two deprecation warnings with Python 2.6
Patch2:		mrepo-python26.patch
#Patch provided by Tom McLaughlin to fix repoview option parsing
Patch3:     mrepo-repoview_options.patch
BuildRoot:	%(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)
BuildArch:	noarch

BuildRequires:	python-devel

# Needed for operation
Requires:	createrepo
# For SELinux compatibility
Requires:	libselinux-python
## For dir ownership
# vixie-cron in older distros, cronie in newer ones; filelist of sbindir is always available
Requires:	%{_sbindir}/crond
Requires:	webserver
Requires:	logrotate

# For services
Requires(post):		chkconfig
Requires(preun):	chkconfig
Requires(preun):	initscripts
Requires(postun):	initscripts


%description
mrepo builds a local Apt/Yum RPM repository from local ISO files,
downloaded updates and extra packages from RHN and 3rd party
repositories.

It can download all updates and extras automatically, creates
the repository structure and meta-data, enables HTTP access to
the repository and creates a directory-structure for remote
network installations using PXE/TFTP.

mrepo supports ftp, http, sftp, rsync, rhn and other download methods.

With mrepo, you can enable your laptop or a local server to provide
updates for the whole network and provide the proper files to
allow installations via the network.

%prep
%setup -q
%patch0 -p1 -b .init
%patch1 -p1 -b .selinux
%patch2 -p1 -b .python26
%patch3 -p1 -b .repoview_options

rm docs/client-configuration.txt

perl -pi.orig -e 's|^(VERSION)\s*=\s*.+$|$1 = "%{version}"|' mrepo

cat <<EOF >config/mrepo.cron
### Enable this if you want mrepo to daily synchronize
### your distributions and repositories at 2:30am.
#30 2 * * * root /usr/bin/mrepo -q -ug
EOF

cat <<EOF >config/mrepo.conf
### Configuration file for mrepo

### The [main] section allows to override mrepo's default settings
### The mrepo-example.conf gives an overview of all the possible settings
[main]
srcdir = /var/mrepo
wwwdir = /var/www/mrepo
confdir = /etc/mrepo.conf.d
arch = i386 

mailto = root@localhost
smtp-server = localhost

#rhnlogin = username:password

### Any other section is considered a definition for a distribution
### You can put distribution sections in /etc/mrepo.conf.d/
### Examples can be found in the documentation at:
### %{_docdir}/%{name}-%{version}/dists/.
EOF

%build

%install
rm -rf %{buildroot}
make install DESTDIR="%{buildroot}"

%post
/sbin/chkconfig --add mrepo

%preun
if [ $1 = 0 ]; then
	/sbin/service mrepo stop >/dev/null 2>&1 || :
	/sbin/chkconfig --del mrepo
fi

%postun
if [ "$1" -ge "1" ] ; then
    /sbin/service mrepo condrestart >/dev/null 2>&1 || :
fi

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog COPYING README THANKS TODO WISHLIST config/*.conf config/dists/ docs/*
%config(noreplace) %{_sysconfdir}/cron.d/mrepo
%config(noreplace) %{_sysconfdir}/httpd/conf.d/mrepo.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/mrepo
%config(noreplace) %{_sysconfdir}/mrepo.conf
%config(noreplace) %{_sysconfdir}/mrepo.conf.d/
%{_sysconfdir}/rc.d/init.d/mrepo
%{_bindir}/gensystemid
%{_bindir}/rhnget
%{_bindir}/mrepo
%{_bindir}/youget
%{_datadir}/mrepo/
%{_localstatedir}/cache/mrepo/
%{_localstatedir}/www/mrepo/
%{_localstatedir}/mrepo/

%changelog
* Wed Aug 04 2010 James Findley <sixy@gmx.com> - 0.8.7-2
- Patch to fix repoview options (#620788).

* Thu Jul 08 2010 James Findley <sixy@gmx.com> - 0.8.7-1
- Update to release 0.8.7 (fixes #610140 and #604277).
- Patch to fix two deprecation warnings on python 2.6.
- Patched initscript to fix #590233.

* Mon May 10 2010 Jussi Lehtola <jussilehtola@fedoraproject.org> - 0.8.6-6
- Patch to get iso mounting working with SElinux (#589755).

* Sun Oct 18 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 0.8.6-5
- Generalize webserver requirement.

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.6-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Sun Jul 12 2009 Sandro Mathys <red@fedoraproject.org> - 0.8.6-3
- Changed the usage of macros to get the spec file to work in EL, too.

* Sun Jul 12 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 0.8.6-2
- Review fixes.

* Sun Jul 12 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 0.8.6-1
- Update to 0.8.6.

* Wed May 20 2009 Jussi Lehtola <jussilehtola@fedoraproject.org> - 0.8.4-2
- Spec modifications for inclusion into Fedora.

* Wed Dec 13 2006 Dag Wieers <dag@wieers.com> - 0.8.4-1
- Updated to release 0.8.4.
- Package renamed from yam to mrepo.

* Sat Oct 21 2006 Dag Wieers <dag@wieers.com> - 0.8.3-2
- Get rid of specific createrepo version now that Yam works with upstream.

* Sun Oct 15 2006 Dag Wieers <dag@wieers.com> - 0.8.3-1
- Updated to release 0.8.3.

* Wed Sep 20 2006 Dag Wieers <dag@wieers.com> - 0.8.2-1
- Updated to release 0.8.2.

* Fri Mar 10 2006 Dag Wieers <dag@wieers.com> - 0.8.0-2
- Added gensystemid to installation. (Ian Forde)

* Thu Mar 09 2006 Dag Wieers <dag@wieers.com> - 0.8.0-1
- Updated to release 0.8.0.

* Fri Mar 25 2005 Dag Wieers <dag@wieers.com> - 0.7.3-1
- Updated to release 0.7.3.

* Fri Jan 07 2005 Dag Wieers <dag@wieers.com> - 0.7.2-2
- Add %%post and %%postun scripts. (Bert de Bruijn)

* Fri Dec 31 2004 Dag Wieers <dag@wieers.com> - 0.7.2-1
- Updated to release 0.7.2.

* Sun Nov 07 2004 Dag Wieers <dag@wieers.com> - 0.7.1-1
- Updated to release 0.7.1.

* Sun Oct 10 2004 Dag Wieers <dag@wieers.com> - 0.7-1
- Updated to release 0.7.

* Fri Aug 27 2004 Dag Wieers <dag@wieers.com> - 0.6.1-1
- Updated to release 0.6.1.

* Wed Aug 25 2004 Dag Wieers <dag@wieers.com> - 0.6-2
- Updated to release 0.6.
- Fix a version problem.

* Thu Aug 19 2004 Dag Wieers <dag@wieers.com> - 0.5-1
- Updated to release 0.5.

* Wed May 19 2004 Dag Wieers <dag@wieers.com> - 0.3-1
- Updated to release 0.3.

* Fri May 14 2004 Dag Wieers <dag@wieers.com> - 0.2-1
- Initial package. (using DAR)
